@@ -51,7 +51,10 @@ fn set_agent_config() -> AtomicResult<Config> {
     match atomic_lib::config::read_config(&agent_config_path) {
         Ok(found) => Ok(found),
         Err(_e) => {
-            println!("No config found. Let's create one!");
+            println!(
+                "No config found at {:?}. Let's create one!",
+                &agent_config_path
+            );
             let server = promptly::prompt("What's the base url of your Atomic Server?")?;
             let agent = promptly::prompt("What's the URL of your Agent?")?;
             let private_key = promptly::prompt("What's the private key of this Agent?")?;
@@ -61,10 +64,7 @@ fn set_agent_config() -> AtomicResult<Config> {
                 private_key,
             };
             atomic_lib::config::write_config(&agent_config_path, config.clone())?;
-            println!(
-                "New config file created at {:?}",
-                agent_config_path.to_str()
-            );
+            println!("New config file created at {:?}", agent_config_path);
             Ok(config)
         }
     }
@@ -111,7 +111,7 @@ fn main() -> AtomicResult<()> {
                     .long("as")
                     .possible_values(&SERIALIZE_OPTIONS)
                     .default_value("pretty")
-                    .help(&"Serialization format")
+                    .help("Serialization format")
                     .takes_value(true)
                 )
         )
@@ -140,7 +140,7 @@ fn main() -> AtomicResult<()> {
                     .long("as")
                     .possible_values(&SERIALIZE_OPTIONS)
                     .default_value("pretty")
-                    .help(&"Serialization format")
+                    .help("Serialization format")
                     .takes_value(true)
                 )
         )
@@ -192,6 +192,14 @@ fn main() -> AtomicResult<()> {
                     .required(true)
                 )
         )
+        .subcommand(
+            SubCommand::with_name("config")
+                .about("Returns the path of the config file")
+                .arg(Arg::with_name("subject")
+                    .help("Subject URL or bookmark of the resource to be destroyed")
+                    .required(true)
+                )
+        )
         .subcommand(SubCommand::with_name("list").about("List all bookmarks"))
         .subcommand(SubCommand::with_name("validate").about("Validates the store").setting(AppSettings::Hidden))
         .get_matches();
